@@ -1,10 +1,10 @@
 ;;; rainbow-mode.el --- Colorize color names in buffers
 
-;; Copyright (C) 2010-2019 Free Software Foundation, Inc
+;; Copyright (C) 2010-2020 Free Software Foundation, Inc
 
 ;; Author: Julien Danjou <julien@danjou.info>
 ;; Keywords: faces
-;; Version: 1.0.3
+;; Version: 1.0.5
 
 ;; This file is part of GNU Emacs.
 
@@ -45,9 +45,9 @@
 ;;; Hexadecimal colors
 
 (defvar rainbow-hexadecimal-colors-font-lock-keywords
-  '(("[^&]\\(#\\(?:[0-9a-fA-F]\\{3\\}\\)+\\{1,4\\}\\)"
+  '(("[^&]\\(#\\(?:[0-9a-fA-F]\\{3\\}\\)\\{1,4\\}\\)"
      (1 (rainbow-colorize-itself 1)))
-    ("^\\(#\\(?:[0-9a-fA-F]\\{3\\}\\)+\\{1,4\\}\\)"
+    ("^\\(#\\(?:[0-9a-fA-F]\\{3\\}\\)\\{1,4\\}\\)"
      (0 (rainbow-colorize-itself)))
     ("[Rr][Gg][Bb]:[0-9a-fA-F]\\{1,4\\}/[0-9a-fA-F]\\{1,4\\}/[0-9a-fA-F]\\{1,4\\}"
      (0 (rainbow-colorize-itself)))
@@ -1130,7 +1130,7 @@ Return a value between 0 and 1."
 ;;; Mode
 
 (defun rainbow-turn-on ()
-  "Turn on raibow-mode."
+  "Turn on rainbow-mode."
   (font-lock-add-keywords nil
                           rainbow-hexadecimal-colors-font-lock-keywords
                           t)
@@ -1212,6 +1212,18 @@ This will fontify with colors the string like \"#aabbcc\" or \"blue\"."
 
 ;;;; ChangeLog:
 
+;; 2020-07-28  Julien Danjou  <julien@danjou.info>
+;; 
+;; 	fix(rainbow_mode): remove spurious + in regex
+;; 
+;; 	Thanks Peder Stray for the report and suggestion.
+;; 
+;; 2020-03-30  Julien Danjou  <julien@danjou.info>
+;; 
+;; 	fix(rainbow-mode): fix typo in docstring
+;; 
+;; 	Thanks Bauke Jan Douma <bjdouma@xs4all.nl>
+;; 
 ;; 2019-12-23  Julien Danjou  <julien@danjou.info>
 ;; 
 ;; 	Release rainbow-mode 1.0.3
